==> haskell-hjsonschema-1.9.0-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonschema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonschema
version: 1.9.0
id: hjsonschema-1.9.0-HSDtynvAtNNG99xiUdjcf3
key: hjsonschema-1.9.0-HSDtynvAtNNG99xiUdjcf3
license: MIT
maintainer: ian@housejeffries.com
author: Ian Grant Jeffries
homepage: https://github.com/seagreen/hjsonschema
synopsis: JSON Schema library
category: Data
abi: 414a5567e7549fd87871dd474acc4647
exposed: True
exposed-modules:
    JSONSchema.Draft4 JSONSchema.Draft4.Failure
    JSONSchema.Draft4.Schema JSONSchema.Draft4.Spec JSONSchema.Fetch
    JSONSchema.Types JSONSchema.Validator.Draft4
    JSONSchema.Validator.Draft4.Any JSONSchema.Validator.Draft4.Array
    JSONSchema.Validator.Draft4.Number
    JSONSchema.Validator.Draft4.Object
    JSONSchema.Validator.Draft4.String JSONSchema.Validator.Reference
    JSONSchema.Validator.Types JSONSchema.Validator.Utils
hidden-modules: JSONSchema.Validator.Draft4.Object.Properties
                Import
import-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonschema-1.9.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonschema-1.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hjsonschema-1.9.0
hs-libraries: HShjsonschema-1.9.0-HSDtynvAtNNG99xiUdjcf3
depends:
    base-4.11.1.0 aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf
    bytestring-0.10.8.2 containers-0.5.11.0
    file-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK filepath-1.4.2
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    hjsonpointer-1.4.0-1LrkV30wFF7JS8sbY9sc68
    http-client-0.5.13-BDPgLPnNEzzAG7Py70CdWs
    http-client-tls-0.3.5.3-4gGcoaLAGPL3I1eY2hx2qR
    http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq
    pcre-heavy-1.0.0.2-58RdvUDLwp4EpDGUdd3hlZ
    profunctors-5.2.2-37ntygF7oMm9NCRo9oIsue
    protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    safe-exceptions-0.1.7.0-BNEDd37HEgdKajKqywmozH
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf=099629a1e097a2a1a4c1ce1f1c4a7711
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             file-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK=480b24a4b596c19b5b43e12ca8596adb
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             hjsonpointer-1.4.0-1LrkV30wFF7JS8sbY9sc68=f1cd286ada2d862212fd29c3de46b883
             http-client-0.5.13-BDPgLPnNEzzAG7Py70CdWs=fa6eec72c73742ffff505285f6de59d8
             http-client-tls-0.3.5.3-4gGcoaLAGPL3I1eY2hx2qR=85b26cc28437727851175622157afe50
             http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq=681a4d4f5ae8e517c4372dabe00b35c0
             pcre-heavy-1.0.0.2-58RdvUDLwp4EpDGUdd3hlZ=5d110c2371f07c45ab0948a0bf6cb488
             profunctors-5.2.2-37ntygF7oMm9NCRo9oIsue=aa07697603deaf24352b3a2b5b95e403
             protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3=bc01b9ed24516101c7701c9e7840f4f3
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             safe-exceptions-0.1.7.0-BNEDd37HEgdKajKqywmozH=f1281846735a004ce12cb3e5caaff091
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-hjsonschema/html/hjsonschema.haddock
haddock-html: /usr/share/doc/haskell-hjsonschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsonschema-1.9.0-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hjsonschema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsonschema
version: 1.9.0
id: hjsonschema-1.9.0-61O6Qo00AW67uOOBtOiSBU
key: hjsonschema-1.9.0-61O6Qo00AW67uOOBtOiSBU
license: MIT
maintainer: ian@housejeffries.com
author: Ian Grant Jeffries
homepage: https://github.com/seagreen/hjsonschema
synopsis: JSON Schema library
category: Data
abi: 2f68b53d5113e988a74c0d23f436e992
exposed: True
exposed-modules:
    JSONSchema.Draft4 JSONSchema.Draft4.Failure
    JSONSchema.Draft4.Schema JSONSchema.Draft4.Spec JSONSchema.Fetch
    JSONSchema.Types JSONSchema.Validator.Draft4
    JSONSchema.Validator.Draft4.Any JSONSchema.Validator.Draft4.Array
    JSONSchema.Validator.Draft4.Number
    JSONSchema.Validator.Draft4.Object
    JSONSchema.Validator.Draft4.String JSONSchema.Validator.Reference
    JSONSchema.Validator.Types JSONSchema.Validator.Utils
hidden-modules: JSONSchema.Validator.Draft4.Object.Properties
                Import
import-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonschema-1.9.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hjsonschema-1.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hjsonschema-1.9.0
hs-libraries: HShjsonschema-1.9.0-61O6Qo00AW67uOOBtOiSBU
depends:
    base-4.11.1.0 aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y
    bytestring-0.10.8.2 containers-0.5.11.0
    file-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK filepath-1.4.2
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    hjsonpointer-1.4.0-YfcZUFbla34QJD44jd8iA
    http-client-0.5.13.1-E2oTnwSZQmdIh914s8ng5x
    http-client-tls-0.3.5.3-1zpUVPwvh5wHxc5Fk2W0Kx
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
    pcre-heavy-1.0.0.2-41QU5UsWJsMGC7unxbRGk5
    profunctors-5.3-EutOmUEm2s6G0y6whclMzu
    protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    safe-exceptions-0.1.7.0-IiYzP2iUv0fJkb2SM367bp
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y text-1.2.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             file-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK=480b24a4b596c19b5b43e12ca8596adb
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             hjsonpointer-1.4.0-YfcZUFbla34QJD44jd8iA=2b1a7033d2e54d2510bda4445ddf1ece
             http-client-0.5.13.1-E2oTnwSZQmdIh914s8ng5x=7bfdf5a067b9b51eacef98e312bdcb38
             http-client-tls-0.3.5.3-1zpUVPwvh5wHxc5Fk2W0Kx=c707f91820faa43557a62b2504200a19
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             pcre-heavy-1.0.0.2-41QU5UsWJsMGC7unxbRGk5=3a617e9d574eb1143dff10137ec1300b
             profunctors-5.3-EutOmUEm2s6G0y6whclMzu=cad55c76a7a504e05683794981f51d80
             protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3=bc01b9ed24516101c7701c9e7840f4f3
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             safe-exceptions-0.1.7.0-IiYzP2iUv0fJkb2SM367bp=af06fba0c38a2212bb15428c426fdcd4
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
haddock-interfaces: /usr/share/doc/haskell-hjsonschema/html/hjsonschema.haddock
haddock-html: /usr/share/doc/haskell-hjsonschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
